@@ -24,9 +24,8 @@
 #' @keywords metric
 
 ae_median_sample <- function(true_values, predictions) {
-  median_predictions <- apply(as.matrix(predictions),
-                              MARGIN = 1, # rowwise
-                              FUN = median
+  median_predictions <- apply(
+    as.matrix(predictions), MARGIN = 1, FUN = median # this is rowwise
   )
 
   ae_median <- abs(true_values - median_predictions)
@@ -34,7 +33,6 @@ ae_median_sample <- function(true_values, predictions) {
   return(ae_median)
 }
 
-
 #' @title Squared Error of the Mean (Sample-based Version)
 #'
 #' @description
