@@ -10,14 +10,14 @@ test_that("avail_forecasts() works as expected", {
   expect_equal(nrow(af[is.na(`Number forecasts`)]), 0)
   af <- suppressMessages(
     avail_forecasts(example_quantile,
-      by = c("model")
+     by = "model"
     )
   )
   expect_equal(nrow(af), 4)
   expect_equal(af$`Number forecasts`, c(256, 256, 247, 128))
   af <- suppressMessages(
     avail_forecasts(example_quantile,
-      by = c("model"), collapse = c()
+     by = "model", collapse = c()
     )
   )
   expect_equal(nrow(af), 4)
