@@ -30,26 +30,26 @@ test_that("summarise_scores() handles wrong by argument well", {
 
 test_that("summarise_scores() works with point forecasts in a quantile format", {
   ex <- data.table::copy(example_quantile)
-
-  ex[quantile == 0.5, quantile := NA_real_]
+  ex <- ex[quantile == 0.5][, quantile := NA_real_]
 
   scores <- suppressMessages(score(ex))
 
-  summarise_scores(scores, by = "model",
-                   na.rm = TRUE)
-
-  summarise_scores(scores, by = "model",
-                   na.rm = TRUE,
-                   relative_skill = TRUE)
-
-  scores <- suppressMessages(score(example_point[is.na(quantile)]))
-
+  summarise_scores(scores, by = "model", na.rm = TRUE)
   expect_warning(
     expect_warning(
       summarise_scores(
         scores, by = "model", relative_skill = TRUE, na.rm = TRUE)
     )
   )
+
+  scores_point <- suppressMessages(score(example_point[is.na(quantile)]))
+
+  expect_warning(
+    expect_warning(
+      summarise_scores(
+        scores_point, by = "model", relative_skill = TRUE, na.rm = TRUE)
+    )
+  )
 })
 
 test_that("summarise_scores() can compute relative measures", {
@@ -72,7 +72,7 @@ test_that("summarise_scores() can compute relative measures", {
   )
 })
 
-test_that("summarise_scores(): metric is deprecated", {
+test_that("summarise_scores() metric is deprecated", {
   ex <- data.table::copy(example_quantile)
   scores <- suppressMessages(score(ex))
 
@@ -87,4 +87,36 @@ test_that("summarise_scores(): metric is deprecated", {
       scores, by = "model", metric = "auto", relative_skill = TRUE
     )
   )  
-})
\ No newline at end of file
+})
+
+test_that("summarise_scores() across argument works as expected", {
+  ex <- data.table::copy(example_quantile)
+  scores <- suppressMessages(score(ex))[, location_name := NULL]
+
+  expect_error(
+    summarise_scores(
+      scores, by = "model", across = "horizon"
+    ),
+    regexp = "You cannot specify both"
+  )
+  expect_error( 
+    summarise_scores(
+      scores, across = "horizons"
+    ),
+    regexp = "The columns specified in 'across' must be a subset "
+  )
+  expect_error(
+    summarise_scores(
+      scores, across = c("horizon", "horizons"),
+    ),
+    regexp = "The columns specified in 'across' must be a subset"
+  )
+  expect_equal(
+    summarise_scores(
+      scores, across = c("horizon", "model", "forecast_date", "target_end_date")
+    ),
+    summarise_scores(
+      scores, by = c("location", "target_type")
+    )
+  )
+})
